# Data Science Toolbox

Yet Another Data Toolbox: DIETBox (Data scIencE Toolbox), a collection of functions and scripts for my data projects.

## Roadmap


## Structure of the project

0. utils: some general functions to be used anywhere
1. stats
   1. basics
   2. ab
2. storage
   1. json
   2. mongo
   3. models: storage models to easily swap out and replace with another
   4. authenticator
   5. bigquery
   6. spreadsheet
3. analysis
4. visualization
5. geo: geolocation related
6. nlp
7. event generator: fake events of all kinds